package com.xinyilu.system.mapper.itemCategory;

import com.xinyilu.system.domain.itemCategory.TestItemCategory;
import com.xinyilu.system.domain.vo.TestItemCategoryVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 测试项目分类Mapper接口
 *
 * @author jihan
 * @date 2022-08-01
 */
public interface TestItemCategoryMapper {
    /**
     * 查询测试项目分类
     *
     * @param id 测试项目分类主键
     * @return 测试项目分类
     */
    public TestItemCategoryVO selectTestItemCategoryById(Long id);

    /**
     * 查询测试项目分类列表
     *
     * @param testItemCategory 测试项目分类
     * @return 测试项目分类集合
     */
    public List<TestItemCategory> selectTestItemCategoryList(TestItemCategory testItemCategory);

    /**
     * 新增测试项目分类
     *
     * @param testItemCategory 测试项目分类
     * @return 结果
     */
    public int insertTestItemCategory(TestItemCategory testItemCategory);

    /**
     * 修改测试项目分类
     *
     * @param testItemCategory 测试项目分类
     * @return 结果
     */
    public int updateTestItemCategory(TestItemCategory testItemCategory);

    /**
     * 删除测试项目分类
     *
     * @param id 测试项目分类主键
     * @return 结果
     */
    public int deleteTestItemCategoryById(Long id);

    /**
     * 批量删除测试项目分类
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTestItemCategoryByIds(Long[] ids);

    /**
     * 逻辑删除测试项目分类
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int updateTestItemCategoryByIds(Long[] ids);

    /**
     * 根据分类名称 与 分类名称简写 去查询项目分类数据信息
     *
     * @param parentId     父级id
     * @param categoryName 分类名称
     * @return int
     **/
    int getTestItemCategoryIds(@Param("parentId") Long parentId, @Param("categoryName") String categoryName);

    /**
     * 查询测试分类根节点是否存在
     *
     * @return 数量
     */
    int getRootCategoryInfo();
}
